@@ -23,10 +23,14 @@ import tkinter.messagebox as tkMessageBox
 import sqlite3
 import parser
 import tkcalendar
+import random
 
 def Print(val):
     print(val)
 
+def randomom(val):
+    print(random.randint(val))
+
 
 class Make():
     def Life_Calculator():
@@ -421,7 +425,7 @@ class htm1():
         pTime = 0
         cTime = 0
         cap = cv2.VideoCapture(0)
-        detector = handDetector()
+        detector = htm1.handDetector1()
         while True:
             success, img = cap.read()
             img = detector.findHands(img)
@@ -639,7 +643,16 @@ class HandProjects():
                     
             cv2.imshow("WebCam", img)
             cv2.waitKey(1)
-    def Virtual_Painter(folderName,Confidence=0.65,BrushThickness=25,EraserThickness=100,WebCam=0):
+    def Virtual_Painter(folderName="NewHeader",Confidence=0.65,BrushThickness=25,EraserThickness=100,WebCam=0):
+        ##light blue==(173,216,230)in rgb
+        #yellow==rgb(255,255,0)
+        #orange==rgb(255,165,0)
+        import cv2
+        import numpy as np
+        import time
+        import os
+        import HandTrackingModule as htm
+
         folderPath = folderName
         myList = os.listdir(folderPath)
         #print(myList)
@@ -657,7 +670,7 @@ class HandProjects():
         cap.set(4,720)
 
         xp, yp = 0,0
-        detector = htm1.handDetector(detectionCon=Confidence)
+        detector = htm.handDetector(detectionCon=0.65)
 
         brushThickness = BrushThickness
         eraserThickness = EraserThickness
@@ -744,6 +757,7 @@ class HandProjects():
 
             cv2.waitKey(1)
 
+
     def Virtual_Painter_b_g_r(folder):
         #vars
         brushThickness = 20
